pub enum RepositoryState {
Clean,
Merge,
Revert,
RevertSequence,
CherryPick,
CherryPickSequence,
Bisect,
Rebase,
RebaseInteractive,
RebaseMerge,
ApplyMailbox,
ApplyMailboxOrRebase,
}Expand description
A listing of the possible states that a repository can be in.
Variants
Clean
No operation is currently in progress
Merge
A merge is currently in progress
Revert
A revert is currently in progress
RevertSequence
A revert of multiple commits is currently in progress
CherryPick
A cherry pick is currently in progress
CherryPickSequence
A cherry pick of multiple commits is currently in progress
Bisect
A bisect is currently in progress
Rebase
A rebase is currently in progress
RebaseInteractive
An interactive rebase is currently in progress
RebaseMerge
A rebase with a merge conflict is currently in progress
ApplyMailbox
An apply operation is currently in progress
ApplyMailboxOrRebase
A rebase or apply operation is currently in progress