get_cached_memory

Function get_cached_memory 

pub unsafe fn get_cached_memory() -> Result<(ssize_t, ssize_t), Error>
Get the current bytes in cache and the maximum that would be allowed in the cache.

Safety

This function is reading a C global without synchronization, so it is not thread safe, and should only be called before any thread is spawned.