Function git2::opts::set_verify_owner_validation
source · Expand description
Set wheter or not to verify ownership before performing a repository. Enabled by default, but disabling this can lead to code execution vulnerabilities.