AnnotatedCommit

Struct AnnotatedCommit 

pub struct AnnotatedCommit<'repo> { /* private fields */ }
A structure to represent an annotated commit, the input to merge and rebase.

An annotated commit contains information about how it was looked up, which may be useful for functions like merge or rebase to provide context to the operation.

Implementations

Source

impl<'repo> AnnotatedCommit<'repo>

pub fn id(&self) -> Oid

Gets the commit ID that the given git_annotated_commit refers to

pub fn refname(&self) -> Result<&str, Error>

Get the refname that the given git_annotated_commit refers to

pub fn refname_bytes(&self) -> &[u8]

Get the refname that the given git_annotated_commit refers to.