Struct git2::IndexAddOption [−]
pub struct IndexAddOption { /* fields omitted */ }Flags for APIs that add files matching pathspec
Methods
impl IndexAddOption
impl IndexAddOptionpub const DEFAULT: IndexAddOption
DEFAULT: IndexAddOption = IndexAddOption{bits: raw::GIT_INDEX_ADD_DEFAULT as u32,}
pub const FORCE: IndexAddOption
FORCE: IndexAddOption = IndexAddOption{bits: raw::GIT_INDEX_ADD_FORCE as u32,}
pub const DISABLE_PATHSPEC_MATCH: IndexAddOption
DISABLE_PATHSPEC_MATCH: IndexAddOption = IndexAddOption{bits: raw::GIT_INDEX_ADD_DISABLE_PATHSPEC_MATCH as u32,}
pub const CHECK_PATHSPEC: IndexAddOption
CHECK_PATHSPEC: IndexAddOption = IndexAddOption{bits: raw::GIT_INDEX_ADD_CHECK_PATHSPEC as u32,}
pub fn empty() -> IndexAddOption
pub fn empty() -> IndexAddOptionReturns an empty set of flags.
pub fn all() -> IndexAddOption
pub fn all() -> IndexAddOptionReturns the set containing all flags.
pub fn bits(&self) -> u32
pub fn bits(&self) -> u32Returns the raw value of the flags currently stored.
pub fn from_bits(bits: u32) -> Option<IndexAddOption>
pub fn from_bits(bits: u32) -> Option<IndexAddOption>Convert from underlying bit representation, unless that representation contains bits that do not correspond to a flag.
pub fn from_bits_truncate(bits: u32) -> IndexAddOption
pub fn from_bits_truncate(bits: u32) -> IndexAddOptionConvert from underlying bit representation, dropping any bits that do not correspond to flags.
pub fn is_empty(&self) -> bool
pub fn is_empty(&self) -> boolReturns true if no flags are currently stored.
pub fn is_all(&self) -> bool
pub fn is_all(&self) -> boolReturns true if all flags are currently set.
pub fn intersects(&self, other: IndexAddOption) -> bool
pub fn intersects(&self, other: IndexAddOption) -> boolReturns true if there are flags common to both self and other.
pub fn contains(&self, other: IndexAddOption) -> bool
pub fn contains(&self, other: IndexAddOption) -> boolReturns true all of the flags in other are contained within self.
pub fn insert(&mut self, other: IndexAddOption)
pub fn insert(&mut self, other: IndexAddOption)Inserts the specified flags in-place.
pub fn remove(&mut self, other: IndexAddOption)
pub fn remove(&mut self, other: IndexAddOption)Removes the specified flags in-place.
pub fn toggle(&mut self, other: IndexAddOption)
pub fn toggle(&mut self, other: IndexAddOption)Toggles the specified flags in-place.
pub fn set(&mut self, other: IndexAddOption, value: bool)
pub fn set(&mut self, other: IndexAddOption, value: bool)Inserts or removes the specified flags depending on the passed value.
impl IndexAddOption[src]
impl IndexAddOptionpub fn is_default(&self) -> bool[src]
pub fn is_default(&self) -> boolpub fn is_force(&self) -> bool[src]
pub fn is_force(&self) -> boolpub fn is_disable_pathspec_match(&self) -> bool[src]
pub fn is_disable_pathspec_match(&self) -> boolpub fn is_check_pathspec(&self) -> bool[src]
pub fn is_check_pathspec(&self) -> boolTrait Implementations
impl Copy for IndexAddOption
impl Copy for IndexAddOptionimpl PartialEq for IndexAddOption
impl PartialEq for IndexAddOptionfn eq(&self, other: &IndexAddOption) -> bool
fn eq(&self, other: &IndexAddOption) -> boolThis method tests for self and other values to be equal, and is used by ==. Read more
fn ne(&self, other: &IndexAddOption) -> bool
fn ne(&self, other: &IndexAddOption) -> boolThis method tests for !=.
impl Eq for IndexAddOption
impl Eq for IndexAddOptionimpl Clone for IndexAddOption
impl Clone for IndexAddOptionfn clone(&self) -> IndexAddOption
fn clone(&self) -> IndexAddOptionReturns a copy of the value. Read more
fn clone_from(&mut self, source: &Self)1.0.0[src]
fn clone_from(&mut self, source: &Self)Performs copy-assignment from source. Read more
impl PartialOrd for IndexAddOption
impl PartialOrd for IndexAddOptionfn partial_cmp(&self, other: &IndexAddOption) -> Option<Ordering>
fn partial_cmp(&self, other: &IndexAddOption) -> Option<Ordering>This method returns an ordering between self and other values if one exists. Read more
fn lt(&self, other: &IndexAddOption) -> bool
fn lt(&self, other: &IndexAddOption) -> boolThis method tests less than (for self and other) and is used by the < operator. Read more
fn le(&self, other: &IndexAddOption) -> bool
fn le(&self, other: &IndexAddOption) -> boolThis method tests less than or equal to (for self and other) and is used by the <= operator. Read more
fn gt(&self, other: &IndexAddOption) -> bool
fn gt(&self, other: &IndexAddOption) -> boolThis method tests greater than (for self and other) and is used by the > operator. Read more
fn ge(&self, other: &IndexAddOption) -> bool
fn ge(&self, other: &IndexAddOption) -> boolThis method tests greater than or equal to (for self and other) and is used by the >= operator. Read more
impl Ord for IndexAddOption
impl Ord for IndexAddOptionfn cmp(&self, other: &IndexAddOption) -> Ordering
fn cmp(&self, other: &IndexAddOption) -> OrderingThis method returns an Ordering between self and other. Read more
fn max(self, other: Self) -> Self1.21.0[src]
fn max(self, other: Self) -> SelfCompares and returns the maximum of two values. Read more
fn min(self, other: Self) -> Self1.21.0[src]
fn min(self, other: Self) -> SelfCompares and returns the minimum of two values. Read more
impl Hash for IndexAddOption
impl Hash for IndexAddOptionfn hash<__H: Hasher>(&self, state: &mut __H)
fn hash<__H: Hasher>(&self, state: &mut __H)Feeds this value into the given [Hasher]. Read more
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, 1.3.0[src]
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, Feeds a slice of this type into the given [Hasher]. Read more
impl Debug for IndexAddOption
impl Debug for IndexAddOptionimpl Binary for IndexAddOption
impl Binary for IndexAddOptionimpl Octal for IndexAddOption
impl Octal for IndexAddOptionimpl LowerHex for IndexAddOption
impl LowerHex for IndexAddOptionimpl UpperHex for IndexAddOption
impl UpperHex for IndexAddOptionimpl BitOr for IndexAddOption
impl BitOr for IndexAddOptiontype Output = IndexAddOption
The resulting type after applying the | operator.
fn bitor(self, other: IndexAddOption) -> IndexAddOption
fn bitor(self, other: IndexAddOption) -> IndexAddOptionReturns the union of the two sets of flags.
impl BitOrAssign for IndexAddOption
impl BitOrAssign for IndexAddOptionfn bitor_assign(&mut self, other: IndexAddOption)
fn bitor_assign(&mut self, other: IndexAddOption)Adds the set of flags.
impl BitXor for IndexAddOption
impl BitXor for IndexAddOptiontype Output = IndexAddOption
The resulting type after applying the ^ operator.
fn bitxor(self, other: IndexAddOption) -> IndexAddOption
fn bitxor(self, other: IndexAddOption) -> IndexAddOptionReturns the left flags, but with all the right flags toggled.
impl BitXorAssign for IndexAddOption
impl BitXorAssign for IndexAddOptionfn bitxor_assign(&mut self, other: IndexAddOption)
fn bitxor_assign(&mut self, other: IndexAddOption)Toggles the set of flags.
impl BitAnd for IndexAddOption
impl BitAnd for IndexAddOptiontype Output = IndexAddOption
The resulting type after applying the & operator.
fn bitand(self, other: IndexAddOption) -> IndexAddOption
fn bitand(self, other: IndexAddOption) -> IndexAddOptionReturns the intersection between the two sets of flags.
impl BitAndAssign for IndexAddOption
impl BitAndAssign for IndexAddOptionfn bitand_assign(&mut self, other: IndexAddOption)
fn bitand_assign(&mut self, other: IndexAddOption)Disables all flags disabled in the set.
impl Sub for IndexAddOption
impl Sub for IndexAddOptiontype Output = IndexAddOption
The resulting type after applying the - operator.
fn sub(self, other: IndexAddOption) -> IndexAddOption
fn sub(self, other: IndexAddOption) -> IndexAddOptionReturns the set difference of the two sets of flags.
impl SubAssign for IndexAddOption
impl SubAssign for IndexAddOptionfn sub_assign(&mut self, other: IndexAddOption)
fn sub_assign(&mut self, other: IndexAddOption)Disables all flags enabled in the set.
impl Not for IndexAddOption
impl Not for IndexAddOptiontype Output = IndexAddOption
The resulting type after applying the ! operator.
fn not(self) -> IndexAddOption
fn not(self) -> IndexAddOptionReturns the complement of this set of flags.
impl Extend<IndexAddOption> for IndexAddOption
impl Extend<IndexAddOption> for IndexAddOptionfn extend<T: IntoIterator<Item = IndexAddOption>>(&mut self, iterator: T)
fn extend<T: IntoIterator<Item = IndexAddOption>>(&mut self, iterator: T)Extends a collection with the contents of an iterator. Read more
impl FromIterator<IndexAddOption> for IndexAddOption
impl FromIterator<IndexAddOption> for IndexAddOptionfn from_iter<T: IntoIterator<Item = IndexAddOption>>(
iterator: T
) -> IndexAddOption
fn from_iter<T: IntoIterator<Item = IndexAddOption>>(
iterator: T
) -> IndexAddOptionCreates a value from an iterator. Read more
impl Default for IndexAddOption[src]
impl Default for IndexAddOptionAuto Trait Implementations
impl Send for IndexAddOption
impl Send for IndexAddOptionimpl Sync for IndexAddOption
impl Sync for IndexAddOption