pub struct PushUpdate<'a> { /* private fields */ }Expand description
Represents an update which will be performed on the remote during push.
Implementations
Sourceimpl PushUpdate<'_>
impl PushUpdate<'_>
Sourcepub fn src_refname_bytes(&self) -> &[u8] ⓘ
pub fn src_refname_bytes(&self) -> &[u8] ⓘ
Returns the source name of the reference as a byte slice.
Sourcepub fn src_refname(&self) -> Result<&str, Error>
pub fn src_refname(&self) -> Result<&str, Error>
Returns the source name of the reference.
Sourcepub fn dst_refname_bytes(&self) -> &[u8] ⓘ
pub fn dst_refname_bytes(&self) -> &[u8] ⓘ
Returns the name of the reference to update on the server as a byte slice.
Sourcepub fn dst_refname(&self) -> Result<&str, Error>
pub fn dst_refname(&self) -> Result<&str, Error>
Returns the name of the reference to update on the server.