Refdb

Struct Refdb 

pub struct Refdb<'repo> { /* private fields */ }
A structure to represent a git reference database.

Implementations

Source

impl<'repo> Refdb<'repo>

pub fn compress(&self) -> Result<(), Error>

Suggests that the reference database compress or optimize its references. This mechanism is implementation specific. For on-disk reference databases, for example, this may pack all loose references.