Struct git2::WorktreePruneOptions[][src]

pub struct WorktreePruneOptions { /* fields omitted */ }
Options to configure how worktree pruning is performed

Implementations

impl WorktreePruneOptions[src]

pub fn new() -> WorktreePruneOptions[src]

Creates a default set of pruning options

By defaults this will prune only worktrees that are no longer valid unlocked and not checked out

pub fn valid(&mut self, valid: bool) -> &mut WorktreePruneOptions[src]

Controls whether valid (still existing on the filesystem) worktrees will be pruned

Defaults to false

pub fn locked(&mut self, locked: bool) -> &mut WorktreePruneOptions[src]

Controls whether locked worktrees will be pruned

Defaults to false

pub fn working_tree(&mut self, working_tree: bool) -> &mut WorktreePruneOptions[src]

Controls whether the actual working tree on the fs is recursively removed

Defaults to false

pub fn raw(&mut self) -> *mut git_worktree_prune_options[src]

Get a set of raw prune options to be used with git_worktree_prune