pub struct StringArray { /* private fields */ }Expand description
A string array structure used by libgit2
Some APIs return arrays of strings which originate from libgit2. This
wrapper type behaves a little like Vec<&str> but does so without copying
the underlying strings until necessary.
Implementations
Sourceimpl StringArray
impl StringArray
Sourcepub fn get(&self, i: usize) -> Result<Option<&str>, Error>
pub fn get(&self, i: usize) -> Result<Option<&str>, Error>
Returns Ok(None) if i is out of bounds.
Sourcepub fn iter(&self) -> Iter<'_> ⓘ
pub fn iter(&self) -> Iter<'_> ⓘ
Returns an iterator over the strings contained within this array.
The iterator yields Option<&str> as it is unknown whether the contents
are utf-8 or not.
Sourcepub fn iter_bytes(&self) -> IterBytes<'_> ⓘ
pub fn iter_bytes(&self) -> IterBytes<'_> ⓘ
Returns an iterator over the strings contained within this array, yielding byte slices.