pub struct AnnotatedCommit<'repo> { /* private fields */ }Expand description
A structure to represent an annotated commit, the input to merge and rebase.
An annotated commit contains information about how it was looked up, which may be useful for functions like merge or rebase to provide context to the operation.
Implementations