Struct git2::Blame [−][src]
pub struct Blame<'repo> { /* fields omitted */ }Opaque structure to hold blame results.
Methods
impl<'repo> Blame<'repo>[src]
impl<'repo> Blame<'repo>pub fn len(&self) -> usize[src]
pub fn len(&self) -> usizeGets the number of hunks that exist in the blame structure.
pub fn is_empty(&self) -> bool[src]
pub fn is_empty(&self) -> boolReturn true is there is no hunk in the blame structure.
pub fn get_index(&self, index: usize) -> Option<BlameHunk>[src]
pub fn get_index(&self, index: usize) -> Option<BlameHunk>Gets the blame hunk at the given index.
pub fn get_line(&self, lineno: usize) -> Option<BlameHunk>[src]
pub fn get_line(&self, lineno: usize) -> Option<BlameHunk>Gets the hunk that relates to the given line number in the newest commit.
ⓘImportant traits for BlameIter<'blame>pub fn iter(&self) -> BlameIter[src]
ⓘImportant traits for BlameIter<'blame>
pub fn iter(&self) -> BlameIterReturns an iterator over the hunks in this blame.