Struct git2::DescribeOptions [−][src]
pub struct DescribeOptions { /* fields omitted */ }Options which indicate how a Describe is created.
Methods
impl DescribeOptions[src]
impl DescribeOptionspub fn new() -> DescribeOptions[src]
pub fn new() -> DescribeOptionsCreates a new blank set of formatting options for a description.
Sets the reference lookup strategy
This behaves like the --tags option to git-decribe.
pub fn describe_all(&mut self) -> &mut Self[src]
pub fn describe_all(&mut self) -> &mut SelfSets the reference lookup strategy
This behaves like the --all option to git-decribe.
pub fn only_follow_first_parent(&mut self, follow: bool) -> &mut Self[src]
pub fn only_follow_first_parent(&mut self, follow: bool) -> &mut SelfIndicates when calculating the distance from the matching tag or reference whether to only walk down the first-parent ancestry.
pub fn show_commit_oid_as_fallback(&mut self, show: bool) -> &mut Self[src]
pub fn show_commit_oid_as_fallback(&mut self, show: bool) -> &mut SelfIf no matching tag or reference is found whether a describe option would normally fail. This option indicates, however, that it will instead fall back to showing the full id of the commit.
pub fn pattern(&mut self, pattern: &str) -> &mut Self[src]
pub fn pattern(&mut self, pattern: &str) -> &mut SelfTrait Implementations
impl Default for DescribeOptions[src]
impl Default for DescribeOptionsAuto Trait Implementations
impl !Send for DescribeOptions
impl !Send for DescribeOptionsimpl !Sync for DescribeOptions
impl !Sync for DescribeOptions