Struct git2::MergeOptions [−][src]
pub struct MergeOptions { /* fields omitted */ }Options to specify when merging.
Methods
impl MergeOptions[src]
impl MergeOptionspub fn new() -> MergeOptions[src]
pub fn new() -> MergeOptionsCreates a default set of merge options.
pub fn find_renames(&mut self, find: bool) -> &mut MergeOptions[src]
pub fn find_renames(&mut self, find: bool) -> &mut MergeOptionsDetect file renames
pub fn rename_threshold(&mut self, thresh: u32) -> &mut MergeOptions[src]
pub fn rename_threshold(&mut self, thresh: u32) -> &mut MergeOptionsSimilarity to consider a file renamed (default 50)
pub fn target_limit(&mut self, limit: u32) -> &mut MergeOptions[src]
pub fn target_limit(&mut self, limit: u32) -> &mut MergeOptionsMaximum similarity sources to examine for renames (default 200).
If the number of rename candidates (add / delete pairs) is greater
than this value, inexact rename detection is aborted. This setting
overrides the merge.renameLimit configuration value.
pub fn recursion_limit(&mut self, limit: u32) -> &mut MergeOptions[src]
pub fn recursion_limit(&mut self, limit: u32) -> &mut MergeOptionsMaximum number of times to merge common ancestors to build a virtual merge base when faced with criss-cross merges. When this limit is reached, the next ancestor will simply be used instead of attempting to merge it. The default is unlimited.
pub fn file_favor(&mut self, favor: FileFavor) -> &mut MergeOptions[src]
pub fn file_favor(&mut self, favor: FileFavor) -> &mut MergeOptionsSpecify a side to favor for resolving conflicts
pub fn standard_style(&mut self, standard: bool) -> &mut MergeOptions[src]
pub fn standard_style(&mut self, standard: bool) -> &mut MergeOptionsCreate standard conflicted merge files
pub fn diff3_style(&mut self, diff3: bool) -> &mut MergeOptions[src]
pub fn diff3_style(&mut self, diff3: bool) -> &mut MergeOptionsCreate diff3-style file
pub fn simplify_alnum(&mut self, simplify: bool) -> &mut MergeOptions[src]
pub fn simplify_alnum(&mut self, simplify: bool) -> &mut MergeOptionsCondense non-alphanumeric regions for simplified diff file
pub fn ignore_whitespace(&mut self, ignore: bool) -> &mut MergeOptions[src]
pub fn ignore_whitespace(&mut self, ignore: bool) -> &mut MergeOptionsIgnore all whitespace
pub fn ignore_whitespace_change(&mut self, ignore: bool) -> &mut MergeOptions[src]
pub fn ignore_whitespace_change(&mut self, ignore: bool) -> &mut MergeOptionsIgnore changes in amount of whitespace
pub fn ignore_whitespace_eol(&mut self, ignore: bool) -> &mut MergeOptions[src]
pub fn ignore_whitespace_eol(&mut self, ignore: bool) -> &mut MergeOptionsIgnore whitespace at end of line
pub fn patience(&mut self, patience: bool) -> &mut MergeOptions[src]
pub fn patience(&mut self, patience: bool) -> &mut MergeOptionsUse the "patience diff" algorithm
pub fn minimal(&mut self, minimal: bool) -> &mut MergeOptions[src]
pub fn minimal(&mut self, minimal: bool) -> &mut MergeOptionsTake extra time to find minimal diff
pub unsafe fn raw(&self) -> *const git_merge_options[src]
pub unsafe fn raw(&self) -> *const git_merge_optionsAcquire a pointer to the underlying raw options.