Struct git2::TreeEntry [−][src]
pub struct TreeEntry<'tree> { /* fields omitted */ }A structure representing an entry inside of a tree. An entry is borrowed from a tree.
Methods
impl<'tree> TreeEntry<'tree>[src]
impl<'tree> TreeEntry<'tree>pub fn id(&self) -> Oid[src]
pub fn id(&self) -> OidGet the id of the object pointed by the entry
pub fn name(&self) -> Option<&str>[src]
pub fn name(&self) -> Option<&str>Get the filename of a tree entry
Returns None if the name is not valid utf-8
pub fn name_bytes(&self) -> &[u8][src]
pub fn name_bytes(&self) -> &[u8]Get the filename of a tree entry
pub fn to_object<'a>(&self, repo: &'a Repository) -> Result<Object<'a>, Error>[src]
pub fn to_object<'a>(&self, repo: &'a Repository) -> Result<Object<'a>, Error>Convert a tree entry to the object it points to.
pub fn kind(&self) -> Option<ObjectType>[src]
pub fn kind(&self) -> Option<ObjectType>Get the type of the object pointed by the entry
pub fn filemode(&self) -> i32[src]
pub fn filemode(&self) -> i32Get the UNIX file attributes of a tree entry
pub fn filemode_raw(&self) -> i32[src]
pub fn filemode_raw(&self) -> i32Get the raw UNIX file attributes of a tree entry
pub fn to_owned(&self) -> TreeEntry<'static>[src]
pub fn to_owned(&self) -> TreeEntry<'static>Convert this entry of any lifetime into an owned signature with a static lifetime.
This will use the Clone::clone implementation under the hood.